# django
from django.utils.translation import ugettext_lazy as _


class Countries:
    AF = "AF"
    AX = "AX"
    AL = "AL"
    DZ = "DZ"
    AS = "AS"
    AD = "AD"
    AO = "AO"
    AI = "AI"
    AQ = "AQ"
    AG = "AG"
    AR = "AR"
    AM = "AM"
    AW = "AW"
    AU = "AU"
    AT = "AT"
    AZ = "AZ"
    BS = "BS"
    BH = "BH"
    BD = "BD"
    BB = "BB"
    BY = "BY"
    BE = "BE"
    BZ = "BZ"
    BJ = "BJ"
    BM = "BM"
    BT = "BT"
    BO = "BO"
    BQ = "BQ"
    BA = "BA"
    BW = "BW"
    BV = "BV"
    BR = "BR"
    IO = "IO"
    BN = "BN"
    BG = "BG"
    BF = "BF"
    BI = "BI"
    CV = "CV"
    KH = "KH"
    CM = "CM"
    CA = "CA"
    KY = "KY"
    CF = "CF"
    TD = "TD"
    CL = "CL"
    CN = "CN"
    CX = "CX"
    CC = "CC"
    CO = "CO"
    KM = "KM"
    CG = "CG"
    CD = "CD"
    CK = "CK"
    CR = "CR"
    CI = "CI"
    HR = "HR"
    CU = "CU"
    CW = "CW"
    CY = "CY"
    CZ = "CZ"
    DK = "DK"
    DJ = "DJ"
    DM = "DM"
    DO = "DO"
    EC = "EC"
    EG = "EG"
    SV = "SV"
    GQ = "GQ"
    ER = "ER"
    EE = "EE"
    SZ = "SZ"
    ET = "ET"
    FK = "FK"
    FO = "FO"
    FJ = "FJ"
    FI = "FI"
    FR = "FR"
    GF = "GF"
    PF = "PF"
    TF = "TF"
    GA = "GA"
    GM = "GM"
    GE = "GE"
    DE = "DE"
    GH = "GH"
    GI = "GI"
    GR = "GR"
    GL = "GL"
    GD = "GD"
    GP = "GP"
    GU = "GU"
    GT = "GT"
    GG = "GG"
    GN = "GN"
    GW = "GW"
    GY = "GY"
    HT = "HT"
    HM = "HM"
    VA = "VA"
    HN = "HN"
    HK = "HK"
    HU = "HU"
    IS = "IS"
    IN = "IN"
    ID = "ID"
    IR = "IR"
    IQ = "IQ"
    IE = "IE"
    IM = "IM"
    IL = "IL"
    IT = "IT"
    JM = "JM"
    JP = "JP"
    JE = "JE"
    JO = "JO"
    KZ = "KZ"
    KE = "KE"
    KI = "KI"
    KP = "KP"
    KR = "KR"
    KW = "KW"
    KG = "KG"
    LA = "LA"
    LV = "LV"
    LB = "LB"
    LS = "LS"
    LR = "LR"
    LY = "LY"
    LI = "LI"
    LT = "LT"
    LU = "LU"
    MO = "MO"
    MG = "MG"
    MW = "MW"
    MY = "MY"
    MV = "MV"
    ML = "ML"
    MT = "MT"
    MH = "MH"
    MQ = "MQ"
    MR = "MR"
    MU = "MU"
    YT = "YT"
    MX = "MX"
    FM = "FM"
    MD = "MD"
    MC = "MC"
    MN = "MN"
    ME = "ME"
    MS = "MS"
    MA = "MA"
    MZ = "MZ"
    MM = "MM"
    NA = "NA"
    NR = "NR"
    NP = "NP"
    NL = "NL"
    NC = "NC"
    NZ = "NZ"
    NI = "NI"
    NE = "NE"
    NG = "NG"
    NU = "NU"
    NF = "NF"
    MK = "MK"
    MP = "MP"
    NO = "NO"
    OM = "OM"
    PK = "PK"
    PW = "PW"
    PS = "PS"
    PA = "PA"
    PG = "PG"
    PY = "PY"
    PE = "PE"
    PH = "PH"
    PN = "PN"
    PL = "PL"
    PT = "PT"
    PR = "PR"
    QA = "QA"
    RE = "RE"
    RO = "RO"
    RU = "RU"
    RW = "RW"
    BL = "BL"
    SH = "SH"
    KN = "KN"
    LC = "LC"
    MF = "MF"
    PM = "PM"
    VC = "VC"
    WS = "WS"
    SM = "SM"
    ST = "ST"
    SA = "SA"
    SN = "SN"
    RS = "RS"
    SC = "SC"
    SL = "SL"
    SG = "SG"
    SX = "SX"
    SK = "SK"
    SI = "SI"
    SB = "SB"
    SO = "SO"
    ZA = "ZA"
    GS = "GS"
    SS = "SS"
    ES = "ES"
    LK = "LK"
    SD = "SD"
    SR = "SR"
    SJ = "SJ"
    SE = "SE"
    CH = "CH"
    SY = "SY"
    TW = "TW"
    TJ = "TJ"
    TZ = "TZ"
    TH = "TH"
    TL = "TL"
    TG = "TG"
    TK = "TK"
    TO = "TO"
    TT = "TT"
    TN = "TN"
    TR = "TR"
    TM = "TM"
    TC = "TC"
    TV = "TV"
    UG = "UG"
    UA = "UA"
    AE = "AE"
    GB = "GB"
    UM = "UM"
    US = "US"
    UY = "UY"
    UZ = "UZ"
    VU = "VU"
    VE = "VE"
    VN = "VN"
    VG = "VG"
    VI = "VI"
    WF = "WF"
    EH = "EH"
    YE = "YE"
    ZM = "ZM"
    ZW = "ZW"

    django_model_choices = (
        (AF, _("Afghanistan")),
        (AX, _("Åland Islands")),
        (AL, _("Albania")),
        (DZ, _("Algeria")),
        (AS, _("American Samoa")),
        (AD, _("Andorra")),
        (AO, _("Angola")),
        (AI, _("Anguilla")),
        (AQ, _("Antarctica")),
        (AG, _("Antigua and Barbuda")),
        (AR, _("Argentina")),
        (AM, _("Armenia")),
        (AW, _("Aruba")),
        (AU, _("Australia")),
        (AT, _("Austria")),
        (AZ, _("Azerbaijan")),
        (BS, _("Bahamas")),
        (BH, _("Bahrain")),
        (BD, _("Bangladesh")),
        (BB, _("Barbados")),
        (BY, _("Belarus")),
        (BE, _("Belgium")),
        (BZ, _("Belize")),
        (BJ, _("Benin")),
        (BM, _("Bermuda")),
        (BT, _("Bhutan")),
        (BO, _("Bolivia (Plurinational State of)")),
        (BQ, _("Bonaire, Sint Eustatius and Saba")),
        (BA, _("Bosnia and Herzegovina")),
        (BW, _("Botswana")),
        (BV, _("Bouvet Island")),
        (BR, _("Brazil")),
        (IO, _("British Indian Ocean Territory")),
        (BN, _("Brunei Darussalam")),
        (BG, _("Bulgaria")),
        (BF, _("Burkina Faso")),
        (BI, _("Burundi")),
        (CV, _("Cabo Verde")),
        (KH, _("Cambodia")),
        (CM, _("Cameroon")),
        (CA, _("Canada")),
        (KY, _("Cayman Islands")),
        (CF, _("Central African Republic")),
        (TD, _("Chad")),
        (CL, _("Chile")),
        (CN, _("China")),
        (CX, _("Christmas Island")),
        (CC, _("Cocos (Keeling) Islands")),
        (CO, _("Colombia")),
        (KM, _("Comoros")),
        (CG, _("Congo")),
        (CD, _("Congo (the Democratic Republic of the)")),
        (CK, _("Cook Islands")),
        (CR, _("Costa Rica")),
        (CI, _("Côte d'Ivoire")),
        (HR, _("Croatia")),
        (CU, _("Cuba")),
        (CW, _("Curaçao")),
        (CY, _("Cyprus")),
        (CZ, _("Czechia")),
        (DK, _("Denmark")),
        (DJ, _("Djibouti")),
        (DM, _("Dominica")),
        (DO, _("Dominican Republic")),
        (EC, _("Ecuador")),
        (EG, _("Egypt")),
        (SV, _("El Salvador")),
        (GQ, _("Equatorial Guinea")),
        (ER, _("Eritrea")),
        (EE, _("Estonia")),
        (SZ, _("Eswatini")),
        (ET, _("Ethiopia")),
        (FK, _("Falkland Islands (Malvinas)")),
        (FO, _("Faroe Islands")),
        (FJ, _("Fiji")),
        (FI, _("Finland")),
        (FR, _("France")),
        (GF, _("French Guiana")),
        (PF, _("French Polynesia")),
        (TF, _("French Southern Territories")),
        (GA, _("Gabon")),
        (GM, _("Gambia")),
        (GE, _("Georgia")),
        (DE, _("Germany")),
        (GH, _("Ghana")),
        (GI, _("Gibraltar")),
        (GR, _("Greece")),
        (GL, _("Greenland")),
        (GD, _("Grenada")),
        (GP, _("Guadeloupe")),
        (GU, _("Guam")),
        (GT, _("Guatemala")),
        (GG, _("Guernsey")),
        (GN, _("Guinea")),
        (GW, _("Guinea-Bissau")),
        (GY, _("Guyana")),
        (HT, _("Haiti")),
        (HM, _("Heard Island and McDonald Islands")),
        (VA, _("Holy See")),
        (HN, _("Honduras")),
        (HK, _("Hong Kong")),
        (HU, _("Hungary")),
        (IS, _("Iceland")),
        (IN, _("India")),
        (ID, _("Indonesia")),
        (IR, _("Iran (Islamic Republic of)")),
        (IQ, _("Iraq")),
        (IE, _("Ireland")),
        (IM, _("Isle of Man")),
        (IL, _("Israel")),
        (IT, _("Italy")),
        (JM, _("Jamaica")),
        (JP, _("Japan")),
        (JE, _("Jersey")),
        (JO, _("Jordan")),
        (KZ, _("Kazakhstan")),
        (KE, _("Kenya")),
        (KI, _("Kiribati")),
        (KP, _("Korea (the Democratic People's Republic of)")),
        (KR, _("Korea (the Republic of)")),
        (KW, _("Kuwait")),
        (KG, _("Kyrgyzstan")),
        (LA, _("Lao People's Democratic Republic")),
        (LV, _("Latvia")),
        (LB, _("Lebanon")),
        (LS, _("Lesotho")),
        (LR, _("Liberia")),
        (LY, _("Libya")),
        (LI, _("Liechtenstein")),
        (LT, _("Lithuania")),
        (LU, _("Luxembourg")),
        (MO, _("Macao")),
        (MG, _("Madagascar")),
        (MW, _("Malawi")),
        (MY, _("Malaysia")),
        (MV, _("Maldives")),
        (ML, _("Mali")),
        (MT, _("Malta")),
        (MH, _("Marshall Islands")),
        (MQ, _("Martinique")),
        (MR, _("Mauritania")),
        (MU, _("Mauritius")),
        (YT, _("Mayotte")),
        (MX, _("Mexico")),
        (FM, _("Micronesia (Federated States of)")),
        (MD, _("Moldova (the Republic of)")),
        (MC, _("Monaco")),
        (MN, _("Mongolia")),
        (ME, _("Montenegro")),
        (MS, _("Montserrat")),
        (MA, _("Morocco")),
        (MZ, _("Mozambique")),
        (MM, _("Myanmar")),
        (NA, _("Namibia")),
        (NR, _("Nauru")),
        (NP, _("Nepal")),
        (NL, _("Netherlands")),
        (NC, _("New Caledonia")),
        (NZ, _("New Zealand")),
        (NI, _("Nicaragua")),
        (NE, _("Niger")),
        (NG, _("Nigeria")),
        (NU, _("Niue")),
        (NF, _("Norfolk Island")),
        (MK, _("North Macedonia")),
        (MP, _("Northern Mariana Islands")),
        (NO, _("Norway")),
        (OM, _("Oman")),
        (PK, _("Pakistan")),
        (PW, _("Palau")),
        (PS, _("Palestine, State of")),
        (PA, _("Panama")),
        (PG, _("Papua New Guinea")),
        (PY, _("Paraguay")),
        (PE, _("Peru")),
        (PH, _("Philippines")),
        (PN, _("Pitcairn")),
        (PL, _("Poland")),
        (PT, _("Portugal")),
        (PR, _("Puerto Rico")),
        (QA, _("Qatar")),
        (RE, _("Réunion")),
        (RO, _("Romania")),
        (RU, _("Russian Federation")),
        (RW, _("Rwanda")),
        (BL, _("Saint Barthélemy")),
        (SH, _("Saint Helena, Ascension and Tristan da Cunha")),
        (KN, _("Saint Kitts and Nevis")),
        (LC, _("Saint Lucia")),
        (MF, _("Saint Martin (French part)")),
        (PM, _("Saint Pierre and Miquelon")),
        (VC, _("Saint Vincent and the Grenadines")),
        (WS, _("Samoa")),
        (SM, _("San Marino")),
        (ST, _("Sao Tome and Principe")),
        (SA, _("Saudi Arabia")),
        (SN, _("Senegal")),
        (RS, _("Serbia")),
        (SC, _("Seychelles")),
        (SL, _("Sierra Leone")),
        (SG, _("Singapore")),
        (SX, _("Sint Maarten (Dutch part)")),
        (SK, _("Slovakia")),
        (SI, _("Slovenia")),
        (SB, _("Solomon Islands")),
        (SO, _("Somalia")),
        (ZA, _("South Africa")),
        (GS, _("South Georgia and the South Sandwich Islands")),
        (SS, _("South Sudan")),
        (ES, _("Spain")),
        (LK, _("Sri Lanka")),
        (SD, _("Sudan")),
        (SR, _("Suriname")),
        (SJ, _("Svalbard and Jan Mayen")),
        (SE, _("Sweden")),
        (CH, _("Switzerland")),
        (SY, _("Syrian Arab Republic")),
        (TW, _("Taiwan (Province of China)")),
        (TJ, _("Tajikistan")),
        (TZ, _("Tanzania, the United Republic of")),
        (TH, _("Thailand")),
        (TL, _("Timor-Leste")),
        (TG, _("Togo")),
        (TK, _("Tokelau")),
        (TO, _("Tonga")),
        (TT, _("Trinidad and Tobago")),
        (TN, _("Tunisia")),
        (TR, _("Türkiye")),
        (TM, _("Turkmenistan")),
        (TC, _("Turks and Caicos Islands")),
        (TV, _("Tuvalu")),
        (UG, _("Uganda")),
        (UA, _("Ukraine")),
        (AE, _("United Arab Emirates")),
        (GB, _("United Kingdom of Great Britain and Northern Ireland")),
        (UM, _("United States Minor Outlying Islands")),
        (US, _("United States of America")),
        (UY, _("Uruguay")),
        (UZ, _("Uzbekistan")),
        (VU, _("Vanuatu")),
        (VE, _("Venezuela (Bolivarian Republic of)")),
        (VN, _("Viet Nam")),
        (VG, _("Virgin Islands (British)")),
        (VI, _("Virgin Islands (U.S.)")),
        (WF, _("Wallis and Futuna")),
        (EH, _("Western Sahara")),
        (YE, _("Yemen")),
        (ZM, _("Zambia")),
        (ZW, _("Zimbabwe")),
    )
